Enum mpl_token_auth_rules::error::RuleSetError
source · pub enum RuleSetError {
Show 41 variants
NumericalOverflow,
DataTypeMismatch,
DataSliceUnexpectedIndexError,
IncorrectOwner,
PayloadVecIndexError,
DerivedKeyInvalid,
PayerIsNotSigner,
NotImplemented,
BorshSerializationError,
BorshDeserializationError,
ValueOccupied,
DataIsEmpty,
MessagePackSerializationError,
MessagePackDeserializationError,
MissingAccount,
MissingPayloadValue,
RuleSetOwnerMismatch,
NameTooLong,
OperationNotFound,
RuleAuthorityIsNotSigner,
UnsupportedRuleSetRevMapVersion,
UnsupportedRuleSetVersion,
UnexpectedRuleSetFailure,
RuleSetRevisionNotAvailable,
AdditionalSignerCheckFailed,
PubkeyMatchCheckFailed,
PubkeyListMatchCheckFailed,
PubkeyTreeMatchCheckFailed,
PDAMatchCheckFailed,
ProgramOwnedCheckFailed,
ProgramOwnedListCheckFailed,
ProgramOwnedTreeCheckFailed,
AmountCheckFailed,
FrequencyCheckFailed,
IsWalletCheckFailed,
ProgramOwnedSetCheckFailed,
InvalidCompareOp,
InvalidConstraintType,
RuleSetReadFailed,
DuplicatedOperationName,
AlignmentError,
}Expand description
The various errors that can be returned by the Rule Set program instructions.
Variants
NumericalOverflow
0 - Numerical Overflow
DataTypeMismatch
1 - Data type mismatch
DataSliceUnexpectedIndexError
2 - Data slice unexpected index error
IncorrectOwner
3 - Incorrect account owner
PayloadVecIndexError
4 - PayloadVec Index error.
DerivedKeyInvalid
5 - Derived key invalid
PayerIsNotSigner
6 - Payer is not a signer
NotImplemented
7 - Feature is not implemented yet
BorshSerializationError
8 - Borsh serialization error
BorshDeserializationError
9 - Borsh deserialization error
ValueOccupied
10 - Value in Payload or RuleSet is occupied
DataIsEmpty
11 - Account data is empty
MessagePackSerializationError
12 - MessagePack serialization error
MessagePackDeserializationError
13 - MessagePack deserialization error
MissingAccount
14 - Missing account
MissingPayloadValue
15 - Missing Payload value
RuleSetOwnerMismatch
16 - RuleSet owner must be payer
NameTooLong
17 - Name too long
OperationNotFound
18 - The operation retrieved is not in the selected RuleSet
RuleAuthorityIsNotSigner
19 - Rule authority is not signer
UnsupportedRuleSetRevMapVersion
20 - Unsupported RuleSet header version
UnsupportedRuleSetVersion
21 - Unsupported RuleSet version
UnexpectedRuleSetFailure
22 - Unexpected RuleSet failure
RuleSetRevisionNotAvailable
23 - RuleSet revision not available
AdditionalSignerCheckFailed
24 - Additional Signer check failed
PubkeyMatchCheckFailed
25 - Pubkey Match check failed
PubkeyListMatchCheckFailed
26 - Pubkey List Match check failed
PubkeyTreeMatchCheckFailed
27 - Pubkey Tree Match check failed
PDAMatchCheckFailed
28 - PDA Match check failed
ProgramOwnedCheckFailed
29 - Program Owned check failed
ProgramOwnedListCheckFailed
30 - Program Owned List check failed
ProgramOwnedTreeCheckFailed
31 - Program Owned Tree check failed
AmountCheckFailed
32 - Amount checked failed
FrequencyCheckFailed
33 - Frequency check failed
IsWalletCheckFailed
34 - IsWallet check failed
ProgramOwnedSetCheckFailed
35 - Program Owned Set check failed
InvalidCompareOp
36 - Invalid compare operator
InvalidConstraintType
37 - Invalid constraint type value
RuleSetReadFailed
38 - Deserialization error
DuplicatedOperationName
39 - Duplicated operation name
AlignmentError
40 - Could not determine alignemnt