pub enum RuleSetInstruction {
CreateOrUpdate(CreateOrUpdateArgs),
Validate(ValidateArgs),
WriteToBuffer(WriteToBufferArgs),
PuffRuleSet(PuffRuleSetArgs),
}Expand description
Instructions available in this program.
Variants
CreateOrUpdate(CreateOrUpdateArgs)
This instruction stores a caller-pre-serialized RuleSet into the rule_set PDA account.
Validate(ValidateArgs)
This instruction executes the RuleSet stored in the rule_set PDA account by calling the
RuleSet’s validate method. If any of the Rules contained in the RuleSet have state
information (such as the Frequency rule’s last_update time value), the optional accounts
must be provided in order to save the updated stated in the RuleSet state PDA. Note that
updating the state for a Rule requires that the rule_authority signer matches the Pubkey
stored in the Rule.
WriteToBuffer(WriteToBufferArgs)
This instruction appends a pre-serialized RuleSet chunk into the rule_set PDA account.
Needed with large RuleSets to stay within transaction size limit.
PuffRuleSet(PuffRuleSetArgs)
Add space to the end of a rule set account. Needed with large RuleSets to pre-allocate
the space, to stay within PDA allocation limits.