pub struct AdditionalSigner<'a> {
pub account: &'a Pubkey,
}Expand description
Constraint representing the requirement that An additional signer must be present.
This constraint does not require any Payload values, but the additional signer account
must be provided to Validate via the additional_rule_accounts argument so that whether
it is a signer can be retrieved from its AccountInfo struct.
Fields
account: &'a PubkeyThe public key that must have also signed the transaction.
Implementations
Sourceimpl<'a> AdditionalSigner<'a>
impl<'a> AdditionalSigner<'a>
Sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
Deserialize a constraint from a byte array.