Struct mpl_token_auth_rules::state::constraint::ProgramOwnedList
source · pub struct ProgramOwnedList<'a> {
pub field: &'a Str32,
pub programs: &'a [Pubkey],
}Expand description
Constraint representing a test where the Pubkey must be owned by a program in the list of Pubkeys.
This constraint requires a PayloadType value of PayloadType::Pubkey. The field value in the
rule is used to locate the Pubkey in the payload for which the owner must be a program in the list
in the rule. Note this same Pubkey account must also be provided to Validate via the
additional_rule_accounts argument. This is so that the Pubkey’s owner can be found from its
AccountInfo struct.
Fields
field: &'a Str32The field in the Payload to be compared.
programs: &'a [Pubkey]The program that must own the Pubkey.
Implementations
sourceimpl<'a> ProgramOwnedList<'a>
impl<'a> ProgramOwnedList<'a>
sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
Deserialize a constraint from a byte array.