pub struct PubkeyTreeMatch<'a> {
pub pubkey_field: &'a Str32,
pub proof_field: &'a Str32,
pub root: &'a [u8; 32],
}Expand description
Constraing representing a test where a Pubkey must be a member of the Merkle tree in the rule.
This constraint requires PayloadType values of PayloadType::Pubkey and PayloadType::MerkleProof.
The field values in the Rule are used to locate them in the Payload. The Pubkey and the proof
are used to calculate a Merkle root which is compared against the root stored in the rule.
Fields
pubkey_field: &'a Str32The field in the Payload to be compared when looking for the Pubkey.
proof_field: &'a Str32The field in the Payload to be compared when looking for the Merkle proof.
root: &'a [u8; 32]The root of the Merkle tree.
Implementations
Sourceimpl<'a> PubkeyTreeMatch<'a>
impl<'a> PubkeyTreeMatch<'a>
Sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
Deserialize a constraint from a byte array.