Enum mpl_token_auth_rules::state::Key
source · #[repr(C)]pub enum Key {
Uninitialized = 0,
RuleSet = 1,
Frequency = 2,
}Expand description
The key at the beginning of the serialized account that identifies the account type.
NOTE: This is not used for the RuleSet account, which uses msgpack instead of Borsh for SerDes.
Variants
Uninitialized = 0
An uninitialized account, which has all bytes set to zero by default.
RuleSet = 1
An account containing a RuleSet.
Frequency = 2
An account containing frequency state.