pub struct Amount<'a> {
pub amount: &'a u64,
pub operator: &'a u64,
pub field: &'a Str32,
}Expand description
Constraint representing a comparison against the amount of tokens being transferred.
This constraint requires a PayloadType value of PayloadType::Amount. The field
value in the Rule is used to locate the numerical amount in the payload to compare to
the amount stored in the rule, using the comparison operator stored in the rule.
Fields
amount: &'a u64The amount to be compared against.
operator: &'a u64The operator to be used in the comparison.
field: &'a Str32The field the amount is stored in.
Implementations