Struct mpl_token_auth_rules::state::IsWallet
source · pub struct IsWallet<'a> {
pub field: &'a Str32,
}Expand description
Constraint that represents a test on whether a pubkey can be signed from a client and therefore is a true wallet account or not.
The details of this constraint are as follows: a wallet is defined as being both owned by the
System Program and the address is on-curve. The field value in the rule is used to
locate the Pubkey in the payload that must be on-curve and for which the owner must be
the System Program. Note this same Pubkey account must also be provided to Validate
via the additional_rule_accounts argument. This is so that the Pubkey’s owner can be
found from its AccountInfo struct.
Fields
field: &'a Str32The field in the Payload to be checked.
Implementations
sourceimpl<'a> IsWallet<'a>
impl<'a> IsWallet<'a>
sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
Deserialize a constraint from a byte array.