pub struct PDAMatch<'a> {
    pub program: &'a Pubkey,
    pub pda_field: &'a Str32,
    pub seeds_field: &'a Str32,
}
Constraint representing a test where a resulting PDA derivation of seeds must prove the account is a PDA.

This constraint requires PayloadType values of PayloadType::Seeds. The field values in the Rule are used to locate them in the Payload. The seeds in the Payload and the program ID stored in the Rule are used to derive the PDA from the Payload.

Fields

program: &'a Pubkey

The program used for the PDA derivation. If a zeroed (default) pubkey is used then the account owner is used.

pda_field: &'a Str32

The field in the Payload to be compared when looking for the PDA.

seeds_field: &'a Str32

The field in the Payload to be compared when looking for the seeds.

Implementations

source

impl<'a> PDAMatch<'a>

source

pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>

Deserialize a constraint from a byte array.

source

pub fn serialize( pda_field: String, program: Option<Pubkey>, seeds_field: String ) -> Result<Vec<u8>, RuleSetError>

Serialize a constraint into a byte array.