Struct mpl_token_auth_rules::state::ProgramOwned
source · pub struct ProgramOwned<'a> {
pub program: &'a Pubkey,
pub field: &'a Str32,
}Expand description
Constraint representing a test where a Pubkey must be owned by a given program.
This constraint requires a PayloadType value of PayloadType::Pubkey. The field value in
the rule is used to locate the Pubkey in the payload for which the owner must be the
program in the rule. Note this same Pubkey account must also be provided to Validate
via the additional_rule_accounts argument. This is so that the Pubkey’s owner can be
found from its AccountInfo struct.
Fields
program: &'a PubkeyThe program that must own the Pubkey.
field: &'a Str32The field in the Payload to be compared.
Implementations
sourceimpl<'a> ProgramOwned<'a>
impl<'a> ProgramOwned<'a>
sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
pub fn from_bytes(bytes: &'a [u8]) -> Result<Self, RuleSetError>
Deserialize a constraint from a byte array.