Struct mpl_token_auth_rules::state::RuleSetRevisionMapV1
source · pub struct RuleSetRevisionMapV1 {
pub rule_set_revisions: Vec<usize>,
}Expand description
Revision map used to keep track of where individual RuleSet revisions are stored in the PDA.
See top-level module for description of PDA memory layout.
Fields
rule_set_revisions: Vec<usize>Vec used to map a RuleSet revision number to its location in the PDA.